@charset "utf-8";
@import url(opera.css);

/* Stylesheet for the Opera info document */
/* Copyright 2012 Opera Software */

body {
  border: 0;
  padding: 0;
  margin: 0;
  max-width: none;
}

h1, h2 {
  font: inherit;
  font-weight: bold;
  text-shadow: none;
  color: inherit;
  line-height: 1.2em;
  background: rgba(0,0,0,0.1);
  margin: 0 0 5px -10px;
  border-top: 1px solid rgba(0,0,0,0.1);
  border-bottom: 1px solid rgba(0,0,0,0.1);
  padding: 5px 15px;
}


table {
  width: 100%;
  display: table !important;
}

tr {
  display: table-row !important;
}

tr:nth-child(even) {
  background: transparent;
}

th, td {
  padding: 2px 5px !important;
  display: table-cell !important;
  width: auto;
}

ul {
  padding: 5px;
}
